Learn R Programming

grip (version 0.1.2)

gripui_graph_family_catalog: Catalog of graph families for the geometry explorer app

Description

The catalog is a registry used by `gripui_family_app()` to populate its family selector, presets, parameter controls, builder calls, and source references.

Usage

gripui_graph_family_catalog()

Arguments

Value

A named list of family descriptors.

Examples

Run this code
catalog <- gripui_graph_family_catalog()
names(catalog)
catalog$mesh$function_name

Run the code above in your browser using DataLab