Skip to contents

Run the gripui Shiny application

Usage

run_gripui(
  project,
  host = "127.0.0.1",
  port = getOption("shiny.port"),
  launch.browser = interactive(),
  auto.stop.after = NULL,
  ...
)

Arguments

project

A gripui_project.

host

Host passed to shiny::runApp().

port

Port passed to shiny::runApp().

launch.browser

Whether to launch a browser.

auto.stop.after

Optional delay, in seconds, after which the app stops itself. This is mainly useful for automated examples and tests.

...

Additional arguments passed to shiny::runApp().

Value

Invisibly returns the result of shiny::runApp().

Examples

graph <- list(adj_list = list(2L, c(1L, 3L), 2L))
layouts <- data.frame(
  candidate = "toy.layout",
  stage = "layout",
  seed = 1L,
  status = "ok",
  stringsAsFactors = FALSE
)
project <- gripui_project(graph = graph, layouts = layouts, title = "Toy project")
run_gripui(
  project,
  launch.browser = FALSE,
  quiet = TRUE,
  auto.stop.after = 0.1
)
#> Loading required package: shiny