Learn R Programming

grip (version 0.1.2)

gripui_project: Create a normalized `gripui` project object

Description

Create a normalized `gripui` project object

Usage

gripui_project(
  graph = NULL,
  layouts,
  title = NULL,
  subtitle = NULL,
  notes = NULL
)

Value

An object of class `gripui_project`.

Arguments

graph

Optional graph object used by layout viewers. This may be a single list containing fields such as `adj_list`, `weight_list`, `vertex_data`, and `graph_info`, a named list of such graph objects for multi-stage projects, or `NULL` when only catalog exploration is needed.

layouts

Data frame with one row per realized layout.

title

Optional project title.

subtitle

Optional subtitle.

notes

Optional notes string.

Examples

Run this code
graph <- list(adj_list = list(2L, c(1L, 3L), c(2L, 4L), 3L))
layouts <- data.frame(
  candidate = "path.default",
  stage = "layout",
  seed = 1L,
  status = "ok",
  stringsAsFactors = FALSE
)
project <- gripui_project(graph = graph, layouts = layouts, title = "Path graph")
project$meta$title

Run the code above in your browser using DataLab