Deterministic perforated-grid occupancy helpers
Source:R/graph_helpers.R
perforated_grid_helpers.RdConvenience constructors for finite occupied grids with non-random holes or
channels. These matrices can be passed to edges.occupied.mesh()
or occupied.mesh.surface.graph().
Usage
keep.periodic.holes(
h,
w = h,
hole_period = 4,
hole_height = 1,
hole_width = hole_height,
row_offset = 2,
col_offset = 2
)
keep.staggered.windows(
h,
w = h,
window_height = 1,
window_width = 2,
row_period = 4,
col_period = 5,
row_offset = 2,
col_offset = 2
)
keep.slit.channels(
h,
w = h,
orientation = c("vertical", "horizontal"),
slit_period = 5,
slit_width = 1,
bridge_spacing = 4,
bridge_size = 1,
offset = 2
)
keep.asymmetric.notches(h, w = h, notch_depth = 3, notch_width = 2)Arguments
- h
Number of rows.
- w
Number of columns. Defaults to
h.- hole_period
Spacing between periodic holes.
- hole_height
Height of each removed rectangular hole.
- hole_width
Width of each removed rectangular hole.
- row_offset
Starting row index for the first removed block.
- col_offset
Starting column index for the first removed block.
- window_height
Height of each staggered removed window.
- window_width
Width of each staggered removed window.
- row_period
Vertical spacing between staggered window bands.
- col_period
Horizontal spacing between staggered windows within a band.
- orientation
Whether slit channels run
"vertical"or"horizontal".- slit_period
Spacing between repeated slit channels.
- slit_width
Width of each slit channel.
- bridge_spacing
Spacing between preserved bridge segments.
- bridge_size
Size of each preserved bridge segment along a slit.
- offset
Starting row or column index for the first slit channel.
- notch_depth
Depth of each asymmetric notch cut from a boundary.
- notch_width
Width of the notched opening along that boundary.