Convenience constructors for finite occupied grids with non-random holes or
channels. These matrices can be passed to edges.occupied.mesh()
or occupied.mesh.surface.graph().
keep.periodic.holes(
h,
w = h,
hole_period = 4,
hole_height = 1,
hole_width = hole_height,
row_offset = 2,
col_offset = 2
)keep.staggered.windows(
h,
w = h,
window_height = 1,
window_width = 2,
row_period = 4,
col_period = 5,
row_offset = 2,
col_offset = 2
)
keep.slit.channels(
h,
w = h,
orientation = c("vertical", "horizontal"),
slit_period = 5,
slit_width = 1,
bridge_spacing = 4,
bridge_size = 1,
offset = 2
)
keep.asymmetric.notches(h, w = h, notch_depth = 3, notch_width = 2)
A logical occupancy matrix whose TRUE entries represent
retained cells.
Number of rows.
Number of columns. Defaults to h.
Spacing between periodic holes.
Height of each removed rectangular hole.
Width of each removed rectangular hole.
Starting row index for the first removed block.
Starting column index for the first removed block.
Height of each staggered removed window.
Width of each staggered removed window.
Vertical spacing between staggered window bands.
Horizontal spacing between staggered windows within a band.
Whether slit channels run "vertical" or
"horizontal".
Spacing between repeated slit channels.
Width of each slit channel.
Spacing between preserved bridge segments.
Size of each preserved bridge segment along a slit.
Starting row or column index for the first slit channel.
Depth of each asymmetric notch cut from a boundary.
Width of the notched opening along that boundary.