Applies a rotation defined by azimuth and elevation angles and returns the first two columns of the rotated matrix.
Details
This is the projection used internally by plot.layout when
projection = "ortho" and is exported so that users can pre-project
coordinates for custom plotting.
Examples
edges <- edges.torus(6, 10)
coords3d <- grip(edges, n = max(edges), dim = 3,
preset = "torus", seed = 1)
xy <- project.3d(coords3d)
plot(xy, asp = 1, pch = 16, cex = 0.5)