Learn R Programming

grip (version 0.1.2)

run_gripui: Run the `gripui` Shiny application

Description

Run the `gripui` Shiny application

Usage

run_gripui(
  project,
  host = "127.0.0.1",
  port = getOption("shiny.port"),
  launch.browser = interactive(),
  auto.stop.after = NULL,
  ...
)

Value

Invisibly returns the result of `shiny::runApp()`.

Arguments

project

A `gripui_project`.

host

Host passed to `shiny::runApp()`.

port

Port passed to `shiny::runApp()`.

launch.browser

Whether to launch a browser.

auto.stop.after

Optional delay, in seconds, after which the app stops itself. This is mainly useful for automated examples and tests.

...

Additional arguments passed to `shiny::runApp()`.