Run the `gripui` Shiny application
run_gripui(
project,
host = "127.0.0.1",
port = getOption("shiny.port"),
launch.browser = interactive(),
auto.stop.after = NULL,
...
)Invisibly returns the result of `shiny::runApp()`.
A `gripui_project`.
Host passed to `shiny::runApp()`.
Port passed to `shiny::runApp()`.
Whether to launch a browser.
Optional delay, in seconds, after which the app stops itself. This is mainly useful for automated examples and tests.
Additional arguments passed to `shiny::runApp()`.