Skip to contents

Run the graph-family geometry explorer Shiny application

Usage

run_gripui_family(
  catalog = gripui_graph_family_catalog(),
  title = "Graph Family Geometry Explorer",
  subtitle = "Interactive geometry browser for synthetic benchmark families.",
  host = "127.0.0.1",
  port = getOption("shiny.port"),
  launch.browser = interactive(),
  auto.stop.after = NULL,
  ...
)

Arguments

catalog

Family catalog, usually `gripui_graph_family_catalog()`.

title

Application title.

subtitle

Optional subtitle shown in the sidebar.

host

Host passed to `shiny::runApp()`.

port

Port passed to `shiny::runApp()`.

launch.browser

Whether to launch a browser.

auto.stop.after

Optional delay, in seconds, after which the app stops itself. This is mainly useful for automated examples and tests.

...

Additional arguments passed to `shiny::runApp()`.

Value

Invisibly returns the result of `shiny::runApp()`.

Examples

run_gripui_family(launch.browser = FALSE, quiet = TRUE, auto.stop.after = 0.1)