Convenience constructors for the four-slot triangle masks used by
edges.recursive.triangle.mask() and
recursive.triangle.mask.surface.graph(). The slots correspond
to the three corner subtriangles and the central inverted subtriangle created
by one barycentric refinement of an equilateral triangle.
mask.triangle.classic()mask.triangle.bridge(missing = c("top", "left", "right"))
A named logical vector of length 4.
Which outer corner is omitted in
mask.triangle.bridge().
The returned mask entries are ordered and named as left,
right, top, and center.